@@ -293,13 +293,14 @@ setMethod("getGOFrameData", "GOAllFrame", function(x){x@data})
     ##Test that some KEGGIDs are real and that the evidence codes are legit.
     KEGGIDs <- x[,1]
     kegg_query <- data.frame(keggList("pathway"))
-    realKEGGIDs <- substr(rownames(kegg_query), 9, 13)
+    ids <- rownames(kegg_query)
+    realKEGGIDs <- substr(ids, 4, nchar(ids))
 
     ##Test that the data.frame has some rows of data in it
     if(!dim(x)[1]>0){
       stop("There are no rows of data in the data.frame supplied to make a KEGGFrame.")
     }
-    if(is.na(table(KEGGIDs %in% realKEGGIDs)["TRUE"])){
+    if(!any(KEGGIDs %in% realKEGGIDs)){
       stop("None of elements in the 1st column of your data.frame object are legitimate KEGG IDs.")
     }
     if(length(x[,1]) != length(x[,2])){ ## TODO, I don't think that this is going to test this effectively...  I probbaly need a different test.
