@@ -465,7 +465,7 @@ dbSelectFromL2Rchain <- function(conn, L2Rchain, Lkeys, Rkeys)
     SQLwhat <- paste(cols, collapse=",")
     SQL <- .makeSQL(SQLchunks, SQLwhat, Lkeys, Rkeys)
     data0 <- dbQuery(conn, SQL)
-    names(data0) <- L2Rchain.colnames(L2Rchain)
+    colnames(data0) <- L2Rchain.colnames(L2Rchain)
     if (nrow(data0) != 0)
         return(data0)
     .make0rowDataFrame(L2Rchain.colnames(L2Rchain))
